RoundRect

Struct RoundRect 

pub struct RoundRect { /* private fields */ }
A rectangle with rounded corners. Unlike kurbo::RoundedRect this has one set of radii shared between all corners, but it does support elliptical corners.

Implementations

Source

impl RoundRect

pub fn new(x0: f64, y0: f64, x1: f64, y1: f64, rx: f64, ry: f64) -> Self

Create a new rounded rectangle from minimum and maximum coordinates.

pub fn from_rect(rect: Rect, radii: impl Into<Vec2>) -> Self

Create a new rounded rectangle from a kurbo::Rect and its radii.

pub fn from_points( p0: impl Into<Point>, p1: impl Into<Point>, radii: impl Into<Vec2>, ) -> Self

Create a new rounded rectangle from two points and its radii.

pub fn from_origin_size( origin: impl Into<Point>, size: impl Into<Size>, radii: impl Into<Vec2>, ) -> Self

Create a new rounded rectangle from its origin point, size, and radii.

pub fn from_center_size( origin: impl Into<Point>, size: impl Into<Size>, radii: impl Into<Vec2>, ) -> Self

Create a new rounded rectangle from its center point, size, and radii.

pub fn width(&self) -> f64

Returns the width of the rounded rectangle

pub fn height(&self) -> f64

Returns the height of the rounded rectangle

pub const fn radii(&self) -> Vec2

Returns the radii of the rounded rectangle

pub const fn rect(&self) -> Rect

Returns a rectangle with the same position and size as the rounded rectangle

pub fn origin(&self) -> Point

Returns the origin point of the rounded rectangle

pub fn center(&self) -> Point

Returns the center point of the rounded rectangle

pub fn size(&self) -> Size

Returns the size of the rounded rectangle

pub fn with_origin(self, origin: impl Into<Point>) -> Self

Returns a copy of the rounded rectangle with a new origin point

pub fn with_size(self, size: impl Into<Size>) -> Self

Returns a copy of the rounded rectangle with a new size

pub fn with_radii(self, radii: impl Into<Vec2>) -> Self

Returns a copy of the rounded rectangle with new radii