pub struct RoundRect { /* private fields */ }Expand description
A rectangle with rounded corners. Unlike kurbo::RoundedRect this has one set of radii
shared between all corners, but it does support elliptical corners.
Implementations
Sourceimpl RoundRect
impl RoundRect
Sourcepub fn new(x0: f64, y0: f64, x1: f64, y1: f64, rx: f64, ry: f64) -> Self
pub fn new(x0: f64, y0: f64, x1: f64, y1: f64, rx: f64, ry: f64) -> Self
Create a new rounded rectangle from minimum and maximum coordinates.
Sourcepub fn from_rect(rect: Rect, radii: impl Into<Vec2>) -> Self
pub fn from_rect(rect: Rect, radii: impl Into<Vec2>) -> Self
Create a new rounded rectangle from a kurbo::Rect and its radii.
Sourcepub fn from_points(
p0: impl Into<Point>,
p1: impl Into<Point>,
radii: impl Into<Vec2>,
) -> Self
pub fn from_points( p0: impl Into<Point>, p1: impl Into<Point>, radii: impl Into<Vec2>, ) -> Self
Create a new rounded rectangle from two points and its radii.
Sourcepub fn from_origin_size(
origin: impl Into<Point>,
size: impl Into<Size>,
radii: impl Into<Vec2>,
) -> Self
pub fn from_origin_size( origin: impl Into<Point>, size: impl Into<Size>, radii: impl Into<Vec2>, ) -> Self
Create a new rounded rectangle from its origin point, size, and radii.
Sourcepub fn from_center_size(
origin: impl Into<Point>,
size: impl Into<Size>,
radii: impl Into<Vec2>,
) -> Self
pub fn from_center_size( origin: impl Into<Point>, size: impl Into<Size>, radii: impl Into<Vec2>, ) -> Self
Create a new rounded rectangle from its center point, size, and radii.
Sourcepub const fn rect(&self) -> Rect
pub const fn rect(&self) -> Rect
Returns a rectangle with the same position and size as the rounded rectangle
Sourcepub fn with_origin(self, origin: impl Into<Point>) -> Self
pub fn with_origin(self, origin: impl Into<Point>) -> Self
Returns a copy of the rounded rectangle with a new origin point
Sourcepub fn with_size(self, size: impl Into<Size>) -> Self
pub fn with_size(self, size: impl Into<Size>) -> Self
Returns a copy of the rounded rectangle with a new size
Sourcepub fn with_radii(self, radii: impl Into<Vec2>) -> Self
pub fn with_radii(self, radii: impl Into<Vec2>) -> Self
Returns a copy of the rounded rectangle with new radii